==> cscec5b-rmat-impl-3.0.1-20221027.035804-32-sources.jar: com/ejianc/business/rmat/bean/RestituteMaintainEntity.java <==
package com.ejianc.business.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 维修清单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_rmat_restitute_maintain")
public class RestituteMaintainEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="restitute_id")
    private Long restituteId; // 退赔单主键
    @TableField(value="material_id")
    private Long materialId; // 物料主键
    @TableField(value="material_name")
    private String materialName; // 物料名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物料类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物料类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="maintain_mny")
    private BigDecimal maintainMny; // 维修金金额(无税)
    @TableField(value="maintain_tax_mny")
    private BigDecimal maintainTaxMny; // 维修金金额(含税)
    @TableField(value="maintain_name")
    private String maintainName; // 维修项名称
    @TableField(value="maintain_unit")
    private String maintainUnit; // 维修单位
    @TableField(value="maintain_tax_price")
    private BigDecimal maintainTaxPrice; // 维修项单价
    @TableField(value="maintain_num")
    private BigDecimal maintainNum; // 报修数量
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="rent_unit_id")
    private String rentUnitId; // 计租单位id
    @TableField(value="rent_unit_name")
    private String rentUnitName; // 计租单位
    @TableField(value="unit_id")
    private String unitId; // 档案单位id
    @TableField(value="unit_name")
    private String unitName; // 档案单位
    @TableField(value="real_unit_id")
    private String realUnitId; // 实物单位id
    @TableField(value="real_unit_name")
    private String realUnitName; // 实物单位
    @TableField(value="num")
    private BigDecimal num; // 档案数量
    @TableField(value="rent_num")
    private BigDecimal rentNum; // 计租数量
    @TableField(value="real_num")
    private BigDecimal realNum; // 实物数量
    @TableField(value="rent_trans_scale")
    private BigDecimal rentTransScale; // 计租转换系数
    @TableField(value="real_trans_scale")
    private BigDecimal realTransScale; // 实物转换系数
    
    
    

    public Long getRestituteId() {
        return restituteId;
    }

    public void setRestituteId(Long restituteId) {
        this.restituteId = restituteId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getMaintainMny() {
        return maintainMny;
    }

    public void setMaintainMny(BigDecimal maintainMny) {
        this.maintainMny = maintainMny;
    }
    public BigDecimal getMaintainTaxMny() {
        return maintainTaxMny;
    }

    public void setMaintainTaxMny(BigDecimal maintainTaxMny) {
        this.maintainTaxMny = maintainTaxMny;
    }
    public String getMaintainName() {
        return maintainName;
    }

    public void setMaintainName(String maintainName) {
        this.maintainName = maintainName;
    }
    public String getMaintainUnit() {
        return maintainUnit;
    }

    public void setMaintainUnit(String maintainUnit) {
        this.maintainUnit = maintainUnit;
    }
    public BigDecimal getMaintainTaxPrice() {
        return maintainTaxPrice;
    }

    public void setMaintainTaxPrice(BigDecimal maintainTaxPrice) {
        this.maintainTaxPrice = maintainTaxPrice;
    }
    public BigDecimal getMaintainNum() {
        return maintainNum;
    }

    public void setMaintainNum(BigDecimal maintainNum) {
        this.maintainNum = maintainNum;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }
    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }
    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }
    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }
    
}

==> cscec5b-rmat-impl-3.0.1-20240119.060517-275-sources.jar: com/ejianc/business/rmat/bean/RestituteMaintainEntity.java <==
package com.ejianc.business.rmat.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 维修清单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_rmat_restitute_maintain")
public class RestituteMaintainEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="restitute_id")
    private Long restituteId; // 退赔单主键
    @TableField(value="material_id")
    private Long materialId; // 物料主键
    @TableField(value="material_name")
    private String materialName; // 物料名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物料类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物料类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="maintain_mny")
    private BigDecimal maintainMny; // 维修金金额(无税)
    @TableField(value="maintain_tax_mny")
    private BigDecimal maintainTaxMny; // 维修金金额(含税)
    @TableField(value="maintain_name")
    private String maintainName; // 维修项名称
    @TableField(value="maintain_unit")
    private String maintainUnit; // 维修单位
    @TableField(value="maintain_tax_price")
    private BigDecimal maintainTaxPrice; // 维修项单价
    @TableField(value="maintain_price")
    private BigDecimal maintainPrice; // 维修项单价(无税)
    @TableField(value="maintain_num")
    private BigDecimal maintainNum; // 报修数量
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="rent_unit_id")
    private String rentUnitId; // 计租单位id
    @TableField(value="rent_unit_name")
    private String rentUnitName; // 计租单位
    @TableField(value="unit_id")
    private String unitId; // 档案单位id
    @TableField(value="unit_name")
    private String unitName; // 档案单位
    @TableField(value="real_unit_id")
    private String realUnitId; // 实物单位id
    @TableField(value="real_unit_name")
    private String realUnitName; // 实物单位
    @TableField(value="num")
    private BigDecimal num; // 档案数量
    @TableField(value="rent_num")
    private BigDecimal rentNum; // 计租数量
    @TableField(value="real_num")
    private BigDecimal realNum; // 实物数量
    @TableField(value="rent_trans_scale")
    private BigDecimal rentTransScale; // 计租转换系数
    @TableField(value="real_trans_scale")
    private BigDecimal realTransScale; // 实物转换系数
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    
    

    public Long getRestituteId() {
        return restituteId;
    }

    public void setRestituteId(Long restituteId) {
        this.restituteId = restituteId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getMaintainMny() {
        return maintainMny;
    }

    public void setMaintainMny(BigDecimal maintainMny) {
        this.maintainMny = maintainMny;
    }
    public BigDecimal getMaintainTaxMny() {
        return maintainTaxMny;
    }

    public void setMaintainTaxMny(BigDecimal maintainTaxMny) {
        this.maintainTaxMny = maintainTaxMny;
    }
    public String getMaintainName() {
        return maintainName;
    }

    public void setMaintainName(String maintainName) {
        this.maintainName = maintainName;
    }
    public String getMaintainUnit() {
        return maintainUnit;
    }

    public void setMaintainUnit(String maintainUnit) {
        this.maintainUnit = maintainUnit;
    }
    public BigDecimal getMaintainTaxPrice() {
        return maintainTaxPrice;
    }

    public void setMaintainTaxPrice(BigDecimal maintainTaxPrice) {
        this.maintainTaxPrice = maintainTaxPrice;
    }
    public BigDecimal getMaintainNum() {
        return maintainNum;
    }

    public void setMaintainNum(BigDecimal maintainNum) {
        this.maintainNum = maintainNum;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }
    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }
    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }
    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public BigDecimal getMaintainPrice() {
        return maintainPrice;
    }

    public void setMaintainPrice(BigDecimal maintainPrice) {
        this.maintainPrice = maintainPrice;
    }
}
